@@ -5,6 +5,7 @@ import { notifyManager } from './notifyManager';
 import { focusManager } from './focusManager';
 import { Subscribable } from './subscribable';
 import { getLogger } from './logger';
+import { isCancelledError } from './retryer';
 export var QueryObserver = /*#__PURE__*/function (_Subscribable) {
   _inheritsLoose(QueryObserver, _Subscribable);
 
@@ -89,11 +90,12 @@ export var QueryObserver = /*#__PURE__*/function (_Subscribable) {
 
     if (mounted && (this.currentQuery !== prevQuery || this.options.enabled !== prevOptions.enabled || this.options.staleTime !== prevOptions.staleTime)) {
       this.updateStaleTimeout();
-    } // Update refetch interval if needed
+    }
 
+    var nextRefetchInterval = this.computeRefetchInterval(); // Update refetch interval if needed
 
-    if (mounted && (this.currentQuery !== prevQuery || this.options.enabled !== prevOptions.enabled || this.options.refetchInterval !== prevOptions.refetchInterval)) {
-      this.updateRefetchInterval();
+    if (mounted && (this.currentQuery !== prevQuery || this.options.enabled !== prevOptions.enabled || nextRefetchInterval !== this.currentRefetchInterval)) {
+      this.updateRefetchInterval(nextRefetchInterval);
     }
   };
 
@@ -107,25 +109,32 @@ export var QueryObserver = /*#__PURE__*/function (_Subscribable) {
     return this.currentResult;
   };
 
-  _proto.trackResult = function trackResult(result) {
+  _proto.trackResult = function trackResult(result, defaultedOptions) {
     var _this2 = this;
 
     var trackedResult = {};
+
+    var trackProp = function trackProp(key) {
+      if (!_this2.trackedProps.includes(key)) {
+        _this2.trackedProps.push(key);
+      }
+    };
+
     Object.keys(result).forEach(function (key) {
       Object.defineProperty(trackedResult, key, {
         configurable: false,
         enumerable: true,
         get: function get() {
-          var typedKey = key;
-
-          if (!_this2.trackedProps.includes(typedKey)) {
-            _this2.trackedProps.push(typedKey);
-          }
-
-          return result[typedKey];
+          trackProp(key);
+          return result[key];
         }
       });
     });
+
+    if (defaultedOptions.useErrorBoundary || defaultedOptions.suspense) {
+      trackProp('error');
+    }
+
     return trackedResult;
   };
 
@@ -156,7 +165,11 @@ export var QueryObserver = /*#__PURE__*/function (_Subscribable) {
   };
 
   _proto.refetch = function refetch(options) {
-    return this.fetch(options);
+    return this.fetch(_extends({}, options, {
+      meta: {
+        refetchPage: options == null ? void 0 : options.refetchPage
+      }
+    }));
   };
 
   _proto.fetchOptimistic = function fetchOptimistic(options) {
@@ -212,12 +225,19 @@ export var QueryObserver = /*#__PURE__*/function (_Subscribable) {
     }, timeout);
   };
 
-  _proto.updateRefetchInterval = function updateRefetchInterval() {
+  _proto.computeRefetchInterval = function computeRefetchInterval() {
+    var _this$options$refetch;
+
+    return typeof this.options.refetchInterval === 'function' ? this.options.refetchInterval(this.currentResult.data, this.currentQuery) : (_this$options$refetch = this.options.refetchInterval) != null ? _this$options$refetch : false;
+  };
+
+  _proto.updateRefetchInterval = function updateRefetchInterval(nextInterval) {
     var _this7 = this;
 
     this.clearRefetchInterval();
+    this.currentRefetchInterval = nextInterval;
 
-    if (isServer || this.options.enabled === false || !isValidTimeout(this.options.refetchInterval)) {
+    if (isServer || this.options.enabled === false || !isValidTimeout(this.currentRefetchInterval) || this.currentRefetchInterval === 0) {
       return;
     }
 
@@ -225,12 +245,12 @@ export var QueryObserver = /*#__PURE__*/function (_Subscribable) {
       if (_this7.options.refetchIntervalInBackground || focusManager.isFocused()) {
         _this7.executeFetch();
       }
-    }, this.options.refetchInterval);
+    }, this.currentRefetchInterval);
   };
 
   _proto.updateTimers = function updateTimers() {
     this.updateStaleTimeout();
-    this.updateRefetchInterval();
+    this.updateRefetchInterval(this.computeRefetchInterval());
   };
 
   _proto.clearTimers = function clearTimers() {
@@ -315,7 +335,7 @@ export var QueryObserver = /*#__PURE__*/function (_Subscribable) {
         } // Show placeholder data if needed
 
 
-    if (typeof options.placeholderData !== 'undefined' && typeof data === 'undefined' && status === 'loading') {
+    if (typeof options.placeholderData !== 'undefined' && typeof data === 'undefined' && (status === 'loading' || status === 'idle')) {
       var placeholderData; // Memoize placeholder data
 
       if ((prevResult == null ? void 0 : prevResult.isPlaceholderData) && options.placeholderData === (prevResultOptions == null ? void 0 : prevResultOptions.placeholderData)) {
@@ -363,6 +383,7 @@ export var QueryObserver = /*#__PURE__*/function (_Subscribable) {
       isFetched: state.dataUpdateCount > 0 || state.errorUpdateCount > 0,
       isFetchedAfterMount: state.dataUpdateCount > queryInitialState.dataUpdateCount || state.errorUpdateCount > queryInitialState.errorUpdateCount,
       isFetching: isFetching,
+      isRefetching: isFetching && status !== 'loading',
       isLoadingError: status === 'error' && state.dataUpdatedAt === 0,
       isPlaceholderData: isPlaceholderData,
       isPreviousData: isPreviousData,
@@ -379,10 +400,6 @@ export var QueryObserver = /*#__PURE__*/function (_Subscribable) {
       return true;
     }
 
-    if (result === prevResult) {
-      return false;
-    }
-
     var _this$options = this.options,
         notifyOnChangeProps = _this$options.notifyOnChangeProps,
         notifyOnChangePropsExclusions = _this$options.notifyOnChangePropsExclusions;
@@ -454,7 +471,7 @@ export var QueryObserver = /*#__PURE__*/function (_Subscribable) {
 
     if (action.type === 'success') {
       notifyOptions.onSuccess = true;
-    } else if (action.type === 'error') {
+    } else if (action.type === 'error' && !isCancelledError(action.error)) {
       notifyOptions.onError = true;
     }
 
@@ -519,7 +536,7 @@ function _shouldFetchOnWindowFocus(query, options) {
 }
 
 function shouldFetchOptionally(query, prevQuery, options, prevOptions) {
-  return options.enabled !== false && (query !== prevQuery || prevOptions.enabled === false) && isStale(query, options);
+  return options.enabled !== false && (query !== prevQuery || prevOptions.enabled === false) && (!options.suspense || query.state.status !== 'error' || prevOptions.enabled === false) && isStale(query, options);
 }
 
 function isStale(query, options) {
