@@ -1,11 +1,10 @@
 import _extends from "@babel/runtime/helpers/esm/extends";
 import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
-// @ts-nocheck
 import React from 'react';
 import { useQueryClient } from 'react-query';
 import { matchSorter } from 'match-sorter';
 import useLocalStorage from './useLocalStorage';
-import { useSafeState } from './utils';
+import { useIsMounted, useSafeState } from './utils';
 import { Panel, QueryKeys, QueryKey, Button, Code, Input, Select, ActiveQueryPanel } from './styledComponents';
 import { ThemeProvider, defaultTheme as theme } from './theme';
 import { getQueryStatusLabel, getQueryStatusColor } from './utils';
@@ -24,9 +23,9 @@ export function ReactQueryDevtools(_ref) {
       _ref$position = _ref.position,
       position = _ref$position === void 0 ? 'bottom-left' : _ref$position,
       _ref$containerElement = _ref.containerElement,
-      Container = _ref$containerElement === void 0 ? 'footer' : _ref$containerElement;
-  var rootRef = React.useRef();
-  var panelRef = React.useRef();
+      Container = _ref$containerElement === void 0 ? 'aside' : _ref$containerElement;
+  var rootRef = React.useRef(null);
+  var panelRef = React.useRef(null);
 
   var _useLocalStorage = useLocalStorage('reactQueryDevtoolsOpen', initialIsOpen),
       isOpen = _useLocalStorage[0],
@@ -44,18 +43,22 @@ export function ReactQueryDevtools(_ref) {
       isResizing = _useSafeState2[0],
       setIsResizing = _useSafeState2[1];
 
+  var isMounted = useIsMounted();
+
   var _handleDragStart = function handleDragStart(panelElement, startEvent) {
+    var _panelElement$getBoun;
+
     if (startEvent.button !== 0) return; // Only allow left click for drag
 
     setIsResizing(true);
     var dragInfo = {
-      originalHeight: panelElement.getBoundingClientRect().height,
+      originalHeight: (_panelElement$getBoun = panelElement == null ? void 0 : panelElement.getBoundingClientRect().height) != null ? _panelElement$getBoun : 0,
       pageY: startEvent.pageY
     };
 
     var run = function run(moveEvent) {
       var delta = dragInfo.pageY - moveEvent.pageY;
-      var newHeight = dragInfo.originalHeight + delta;
+      var newHeight = (dragInfo == null ? void 0 : dragInfo.originalHeight) + delta;
       setDevtoolsHeight(newHeight);
 
       if (newHeight < 70) {
@@ -76,19 +79,48 @@ export function ReactQueryDevtools(_ref) {
   };
 
   React.useEffect(function () {
-    setIsResolvedOpen(isOpen);
-  }, [isOpen, isResolvedOpen, setIsResolvedOpen]);
+    setIsResolvedOpen(isOpen != null ? isOpen : false);
+  }, [isOpen, isResolvedOpen, setIsResolvedOpen]); // Toggle panel visibility before/after transition (depending on direction).
+  // Prevents focusing in a closed panel.
+
+  React.useEffect(function () {
+    var ref = panelRef.current;
+
+    if (ref) {
+      var handlePanelTransitionStart = function handlePanelTransitionStart() {
+        if (ref && isResolvedOpen) {
+          ref.style.visibility = 'visible';
+        }
+      };
+
+      var handlePanelTransitionEnd = function handlePanelTransitionEnd() {
+        if (ref && !isResolvedOpen) {
+          ref.style.visibility = 'hidden';
+        }
+      };
+
+      ref.addEventListener('transitionstart', handlePanelTransitionStart);
+      ref.addEventListener('transitionend', handlePanelTransitionEnd);
+      return function () {
+        ref.removeEventListener('transitionstart', handlePanelTransitionStart);
+        ref.removeEventListener('transitionend', handlePanelTransitionEnd);
+      };
+    }
+  }, [isResolvedOpen]);
   React[isServer ? 'useEffect' : 'useLayoutEffect'](function () {
     if (isResolvedOpen) {
-      var _rootRef$current;
+      var _rootRef$current, _rootRef$current$pare;
 
-      var previousValue = (_rootRef$current = rootRef.current) == null ? void 0 : _rootRef$current.parentElement.style.paddingBottom;
+      var previousValue = (_rootRef$current = rootRef.current) == null ? void 0 : (_rootRef$current$pare = _rootRef$current.parentElement) == null ? void 0 : _rootRef$current$pare.style.paddingBottom;
 
       var run = function run() {
-        var _panelRef$current;
+        var _panelRef$current, _rootRef$current2;
 
         var containerHeight = (_panelRef$current = panelRef.current) == null ? void 0 : _panelRef$current.getBoundingClientRect().height;
-        rootRef.current.parentElement.style.paddingBottom = containerHeight + "px";
+
+        if ((_rootRef$current2 = rootRef.current) == null ? void 0 : _rootRef$current2.parentElement) {
+          rootRef.current.parentElement.style.paddingBottom = containerHeight + "px";
+        }
       };
 
       run();
@@ -96,8 +128,13 @@ export function ReactQueryDevtools(_ref) {
       if (typeof window !== 'undefined') {
         window.addEventListener('resize', run);
         return function () {
+          var _rootRef$current3;
+
           window.removeEventListener('resize', run);
-          rootRef.current.parentElement.style.paddingBottom = previousValue;
+
+          if (((_rootRef$current3 = rootRef.current) == null ? void 0 : _rootRef$current3.parentElement) && typeof previousValue === 'string') {
+            rootRef.current.parentElement.style.paddingBottom = previousValue;
+          }
         };
       }
     }
@@ -115,11 +152,14 @@ export function ReactQueryDevtools(_ref) {
   var _toggleButtonProps$st = toggleButtonProps.style,
       toggleButtonStyle = _toggleButtonProps$st === void 0 ? {} : _toggleButtonProps$st,
       onToggleClick = toggleButtonProps.onClick,
-      otherToggleButtonProps = _objectWithoutPropertiesLoose(toggleButtonProps, ["style", "onClick"]);
+      otherToggleButtonProps = _objectWithoutPropertiesLoose(toggleButtonProps, ["style", "onClick"]); // Do not render on the server
 
+
+  if (!isMounted()) return null;
   return /*#__PURE__*/React.createElement(Container, {
     ref: rootRef,
-    className: "ReactQueryDevtools"
+    className: "ReactQueryDevtools",
+    "aria-label": "React Query Devtools"
   }, /*#__PURE__*/React.createElement(ThemeProvider, {
     theme: theme
   }, /*#__PURE__*/React.createElement(ReactQueryDevtoolsPanel, _extends({
@@ -129,13 +169,15 @@ export function ReactQueryDevtools(_ref) {
       position: 'fixed',
       bottom: '0',
       right: '0',
-      zIndex: '99999',
+      zIndex: 99999,
       width: '100%',
       height: devtoolsHeight != null ? devtoolsHeight : 500,
       maxHeight: '90%',
       boxShadow: '0 0 20px rgba(0,0,0,.3)',
       borderTop: "1px solid " + theme.gray,
-      transformOrigin: 'top'
+      transformOrigin: 'top',
+      // visibility will be toggled after transitions, but set initial state here
+      visibility: isOpen ? 'visible' : 'hidden'
     }, panelStyle, isResizing ? {
       transition: "none"
     } : {
@@ -155,16 +197,20 @@ export function ReactQueryDevtools(_ref) {
       return _handleDragStart(panelRef.current, e);
     }
   })), isResolvedOpen ? /*#__PURE__*/React.createElement(Button, _extends({
-    type: "button"
+    type: "button",
+    "aria-label": "Close React Query Devtools",
+    "aria-controls": "ReactQueryDevtoolsPanel",
+    "aria-haspopup": "true",
+    "aria-expanded": "true"
   }, otherCloseButtonProps, {
-    onClick: function onClick() {
+    onClick: function onClick(e) {
       setIsOpen(false);
-      onCloseClick && onCloseClick();
+      onCloseClick && onCloseClick(e);
     },
     style: _extends({
       position: 'fixed',
-      zIndex: '99999',
-      margin: '.5rem',
+      zIndex: 99999,
+      margin: '.5em',
       bottom: 0
     }, position === 'top-right' ? {
       right: '0'
@@ -179,19 +225,22 @@ export function ReactQueryDevtools(_ref) {
     type: "button"
   }, otherToggleButtonProps, {
     "aria-label": "Open React Query Devtools",
-    onClick: function onClick() {
+    "aria-controls": "ReactQueryDevtoolsPanel",
+    "aria-haspopup": "true",
+    "aria-expanded": "false",
+    onClick: function onClick(e) {
       setIsOpen(true);
-      onToggleClick && onToggleClick();
+      onToggleClick && onToggleClick(e);
     },
     style: _extends({
       background: 'none',
       border: 0,
       padding: 0,
       position: 'fixed',
-      zIndex: '99999',
+      zIndex: 99999,
       display: 'inline-flex',
-      fontSize: '1.5rem',
-      margin: '.5rem',
+      fontSize: '1.5em',
+      margin: '.5em',
       cursor: 'pointer',
       width: 'fit-content'
     }, position === 'top-right' ? {
@@ -218,19 +267,22 @@ var getStatusRank = function getStatusRank(q) {
 
 var sortFns = {
   'Status > Last Updated': function StatusLastUpdated(a, b) {
-    return getStatusRank(a) === getStatusRank(b) ? sortFns['Last Updated'](a, b) : getStatusRank(a) > getStatusRank(b) ? 1 : -1;
+    var _sortFns$LastUpdated;
+
+    return getStatusRank(a) === getStatusRank(b) ? (_sortFns$LastUpdated = sortFns['Last Updated']) == null ? void 0 : _sortFns$LastUpdated.call(sortFns, a, b) : getStatusRank(a) > getStatusRank(b) ? 1 : -1;
   },
   'Query Hash': function QueryHash(a, b) {
     return a.queryHash > b.queryHash ? 1 : -1;
   },
   'Last Updated': function LastUpdated(a, b) {
-    return a.state.updatedAt < b.state.updatedAt ? 1 : -1;
+    return a.state.dataUpdatedAt < b.state.dataUpdatedAt ? 1 : -1;
   }
 };
 export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function ReactQueryDevtoolsPanel(props, ref) {
   var _activeQuery$state;
 
-  var isOpen = props.isOpen,
+  var _props$isOpen = props.isOpen,
+      isOpen = _props$isOpen === void 0 ? true : _props$isOpen,
       setIsOpen = props.setIsOpen,
       handleDragStart = props.handleDragStart,
       panelProps = _objectWithoutPropertiesLoose(props, ["isOpen", "setIsOpen", "handleDragStart"]);
@@ -303,29 +355,33 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
   }).length;
   React.useEffect(function () {
     if (isOpen) {
-      return queryCache.subscribe(function () {
+      var unsubscribe = queryCache.subscribe(function () {
         setUnsortedQueries(Object.values(queryCache.getAll()));
-      });
+      }); // re-subscribing after the panel is closed and re-opened won't trigger the callback,
+      // So we'll manually populate our state
+
+      setUnsortedQueries(Object.values(queryCache.getAll()));
+      return unsubscribe;
     }
 
     return undefined;
   }, [isOpen, sort, sortFn, sortDesc, setUnsortedQueries, queryCache]);
 
   var handleRefetch = function handleRefetch() {
-    var promise = activeQuery.fetch();
-    promise.catch(noop);
+    var promise = activeQuery == null ? void 0 : activeQuery.fetch();
+    promise == null ? void 0 : promise.catch(noop);
   };
 
   return /*#__PURE__*/React.createElement(ThemeProvider, {
     theme: theme
   }, /*#__PURE__*/React.createElement(Panel, _extends({
     ref: ref,
-    className: "ReactQueryDevtoolsPanel"
-  }, panelProps, {
-    suppressHydrationWarning: true
-  }), /*#__PURE__*/React.createElement("style", {
+    className: "ReactQueryDevtoolsPanel",
+    "aria-label": "React Query Devtools Panel",
+    id: "ReactQueryDevtoolsPanel"
+  }, panelProps), /*#__PURE__*/React.createElement("style", {
     dangerouslySetInnerHTML: {
-      __html: "\n            .ReactQueryDevtoolsPanel * {\n              scrollbar-color: " + theme.backgroundAlt + " " + theme.gray + ";\n            }\n\n            .ReactQueryDevtoolsPanel *::-webkit-scrollbar, .ReactQueryDevtoolsPanel scrollbar {\n              width: 1rem;\n              height: 1rem;\n            }\n\n            .ReactQueryDevtoolsPanel *::-webkit-scrollbar-track, .ReactQueryDevtoolsPanel scrollbar-track {\n              background: " + theme.backgroundAlt + ";\n            }\n\n            .ReactQueryDevtoolsPanel *::-webkit-scrollbar-thumb, .ReactQueryDevtoolsPanel scrollbar-thumb {\n              background: " + theme.gray + ";\n              border-radius: .5rem;\n              border: 3px solid " + theme.backgroundAlt + ";\n            }\n          "
+      __html: "\n            .ReactQueryDevtoolsPanel * {\n              scrollbar-color: " + theme.backgroundAlt + " " + theme.gray + ";\n            }\n\n            .ReactQueryDevtoolsPanel *::-webkit-scrollbar, .ReactQueryDevtoolsPanel scrollbar {\n              width: 1em;\n              height: 1em;\n            }\n\n            .ReactQueryDevtoolsPanel *::-webkit-scrollbar-track, .ReactQueryDevtoolsPanel scrollbar-track {\n              background: " + theme.backgroundAlt + ";\n            }\n\n            .ReactQueryDevtoolsPanel *::-webkit-scrollbar-thumb, .ReactQueryDevtoolsPanel scrollbar-thumb {\n              background: " + theme.gray + ";\n              border-radius: .5em;\n              border: 3px solid " + theme.backgroundAlt + ";\n            }\n          "
     }
   }), /*#__PURE__*/React.createElement("div", {
     style: {
@@ -346,12 +402,12 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
       maxHeight: '100%',
       overflow: 'auto',
       borderRight: "1px solid " + theme.grayAlt,
-      display: 'flex',
+      display: isOpen ? 'flex' : 'none',
       flexDirection: 'column'
     }
   }, /*#__PURE__*/React.createElement("div", {
     style: {
-      padding: '.5rem',
+      padding: '.5em',
       background: theme.backgroundAlt,
       display: 'flex',
       justifyContent: 'space-between',
@@ -360,7 +416,7 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
   }, /*#__PURE__*/React.createElement(Logo, {
     "aria-hidden": true,
     style: {
-      marginRight: '.5rem'
+      marginRight: '.5em'
     }
   }), /*#__PURE__*/React.createElement("div", {
     style: {
@@ -369,49 +425,38 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
     }
   }, /*#__PURE__*/React.createElement(QueryKeys, {
     style: {
-      marginBottom: '.5rem'
+      marginBottom: '.5em'
     }
   }, /*#__PURE__*/React.createElement(QueryKey, {
-    suppressHydrationWarning: true,
     style: {
       background: theme.success,
       opacity: hasFresh ? 1 : 0.3
     }
-  }, "fresh ", /*#__PURE__*/React.createElement(Code, {
-    suppressHydrationWarning: true
-  }, "(", hasFresh, ")")), ' ', /*#__PURE__*/React.createElement(QueryKey, {
-    suppressHydrationWarning: true,
+  }, "fresh ", /*#__PURE__*/React.createElement(Code, null, "(", hasFresh, ")")), ' ', /*#__PURE__*/React.createElement(QueryKey, {
     style: {
       background: theme.active,
       opacity: hasFetching ? 1 : 0.3
     }
-  }, "fetching", ' ', /*#__PURE__*/React.createElement(Code, {
-    suppressHydrationWarning: true
-  }, "(", hasFetching, ")")), ' ', /*#__PURE__*/React.createElement(QueryKey, {
-    suppressHydrationWarning: true,
+  }, "fetching ", /*#__PURE__*/React.createElement(Code, null, "(", hasFetching, ")")), ' ', /*#__PURE__*/React.createElement(QueryKey, {
     style: {
       background: theme.warning,
       color: 'black',
       textShadow: '0',
       opacity: hasStale ? 1 : 0.3
     }
-  }, "stale ", /*#__PURE__*/React.createElement(Code, {
-    suppressHydrationWarning: true
-  }, "(", hasStale, ")")), ' ', /*#__PURE__*/React.createElement(QueryKey, {
-    suppressHydrationWarning: true,
+  }, "stale ", /*#__PURE__*/React.createElement(Code, null, "(", hasStale, ")")), ' ', /*#__PURE__*/React.createElement(QueryKey, {
     style: {
       background: theme.gray,
       opacity: hasInactive ? 1 : 0.3
     }
-  }, "inactive", ' ', /*#__PURE__*/React.createElement(Code, {
-    suppressHydrationWarning: true
-  }, "(", hasInactive, ")"))), /*#__PURE__*/React.createElement("div", {
+  }, "inactive ", /*#__PURE__*/React.createElement(Code, null, "(", hasInactive, ")"))), /*#__PURE__*/React.createElement("div", {
     style: {
       display: 'flex',
       alignItems: 'center'
     }
   }, /*#__PURE__*/React.createElement(Input, {
     placeholder: "Filter",
+    "aria-label": "Filter by queryhash",
     value: filter != null ? filter : '',
     onChange: function onChange(e) {
       return setFilter(e.target.value);
@@ -421,9 +466,10 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
     },
     style: {
       flex: '1',
-      marginRight: '.5rem'
+      marginRight: '.5em'
     }
   }), !filter ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Select, {
+    "aria-label": "Sort queries",
     value: sort,
     onChange: function onChange(e) {
       return setSort(e.target.value);
@@ -431,7 +477,7 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
     style: {
       flex: '1',
       minWidth: 75,
-      marginRight: '.5rem'
+      marginRight: '.5em'
     }
   }, Object.keys(sortFns).map(function (key) {
     return /*#__PURE__*/React.createElement("option", {
@@ -446,18 +492,19 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
       });
     },
     style: {
-      padding: '.3rem .4rem'
+      padding: '.3em .4em'
     }
   }, sortDesc ? '⬇ Desc' : '⬆ Asc')) : null))), /*#__PURE__*/React.createElement("div", {
-    suppressHydrationWarning: true,
     style: {
       overflowY: 'auto',
       flex: '1'
     }
   }, queries.map(function (query, i) {
+    var isDisabled = query.getObserversCount() > 0 && !query.isActive();
     return /*#__PURE__*/React.createElement("div", {
-      suppressHydrationWarning: true,
       key: query.queryHash || i,
+      role: "button",
+      "aria-label": "Open query details for " + query.queryHash,
       onClick: function onClick() {
         return setActiveQueryHash(activeQueryHash === query.queryHash ? '' : query.queryHash);
       },
@@ -468,11 +515,10 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
         background: query === activeQuery ? 'rgba(255,255,255,.1)' : undefined
       }
     }, /*#__PURE__*/React.createElement("div", {
-      suppressHydrationWarning: true,
       style: {
         flex: '0 0 auto',
-        width: '2rem',
-        height: '2rem',
+        width: '2em',
+        height: '2em',
         background: getQueryStatusColor(query, theme),
         display: 'flex',
         alignItems: 'center',
@@ -481,15 +527,24 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
         textShadow: getQueryStatusLabel(query) === 'stale' ? '0' : '0 0 10px black',
         color: getQueryStatusLabel(query) === 'stale' ? 'black' : 'white'
       }
-    }, query.getObserversCount()), /*#__PURE__*/React.createElement(Code, {
-      suppressHydrationWarning: true,
+    }, query.getObserversCount()), isDisabled ? /*#__PURE__*/React.createElement("div", {
       style: {
-        padding: '.5rem'
+        flex: '0 0 auto',
+        height: '2em',
+        background: theme.gray,
+        display: 'flex',
+        alignItems: 'center',
+        fontWeight: 'bold',
+        padding: '0 0.5em'
+      }
+    }, "disabled") : null, /*#__PURE__*/React.createElement(Code, {
+      style: {
+        padding: '.5em'
       }
     }, "" + query.queryHash));
   }))), activeQuery ? /*#__PURE__*/React.createElement(ActiveQueryPanel, null, /*#__PURE__*/React.createElement("div", {
     style: {
-      padding: '.5rem',
+      padding: '.5em',
       background: theme.backgroundAlt,
       position: 'sticky',
       top: 0,
@@ -497,18 +552,18 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
     }
   }, "Query Details"), /*#__PURE__*/React.createElement("div", {
     style: {
-      padding: '.5rem'
+      padding: '.5em'
     }
   }, /*#__PURE__*/React.createElement("div", {
     style: {
-      marginBottom: '.5rem',
+      marginBottom: '.5em',
       display: 'flex',
       alignItems: 'stretch',
       justifyContent: 'space-between'
     }
   }, /*#__PURE__*/React.createElement(Code, {
     style: {
-      lineHeight: '1.8rem'
+      lineHeight: '1.8em'
     }
   }, /*#__PURE__*/React.createElement("pre", {
     style: {
@@ -518,8 +573,8 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
     }
   }, JSON.stringify(activeQuery.queryKey, null, 2))), /*#__PURE__*/React.createElement("span", {
     style: {
-      padding: '0.3rem .6rem',
-      borderRadius: '0.4rem',
+      padding: '0.3em .6em',
+      borderRadius: '0.4em',
       fontWeight: 'bold',
       textShadow: '0 2px 10px black',
       background: getQueryStatusColor(activeQuery, theme),
@@ -527,7 +582,7 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
     }
   }, getQueryStatusLabel(activeQuery))), /*#__PURE__*/React.createElement("div", {
     style: {
-      marginBottom: '.5rem',
+      marginBottom: '.5em',
       display: 'flex',
       alignItems: 'center',
       justifyContent: 'space-between'
@@ -541,14 +596,14 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
   }, "Last Updated:", ' ', /*#__PURE__*/React.createElement(Code, null, new Date(activeQuery.state.dataUpdatedAt).toLocaleTimeString()))), /*#__PURE__*/React.createElement("div", {
     style: {
       background: theme.backgroundAlt,
-      padding: '.5rem',
+      padding: '.5em',
       position: 'sticky',
       top: 0,
       zIndex: 1
     }
   }, "Actions"), /*#__PURE__*/React.createElement("div", {
     style: {
-      padding: '0.5rem'
+      padding: '0.5em'
     }
   }, /*#__PURE__*/React.createElement(Button, {
     type: "button",
@@ -585,14 +640,14 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
   }, "Remove")), /*#__PURE__*/React.createElement("div", {
     style: {
       background: theme.backgroundAlt,
-      padding: '.5rem',
+      padding: '.5em',
       position: 'sticky',
       top: 0,
       zIndex: 1
     }
   }, "Data Explorer"), /*#__PURE__*/React.createElement("div", {
     style: {
-      padding: '.5rem'
+      padding: '.5em'
     }
   }, /*#__PURE__*/React.createElement(Explorer, {
     label: "Data",
@@ -601,14 +656,14 @@ export var ReactQueryDevtoolsPanel = /*#__PURE__*/React.forwardRef(function Reac
   })), /*#__PURE__*/React.createElement("div", {
     style: {
       background: theme.backgroundAlt,
-      padding: '.5rem',
+      padding: '.5em',
       position: 'sticky',
       top: 0,
       zIndex: 1
     }
   }, "Query Explorer"), /*#__PURE__*/React.createElement("div", {
     style: {
-      padding: '.5rem'
+      padding: '.5em'
     }
   }, /*#__PURE__*/React.createElement(Explorer, {
     label: "Query",
